@@ -1,5 +1,6 @@
 /*
     Copyright (C) 2002-2005, Jason Katz-Brown <jasonkb@mit.edu>
+    Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,33 +24,32 @@
 
 #include "game.h"
 
-class K3ListBox;
+class KListWidget;
 class QHBoxLayout;
-class Q3ListBoxItem;
+class QListWidgetItem;
 class Config;
 
+namespace Kolf
+{
+	class ItemFactory;
+}
+
 class Editor : public QWidget
 {
 	Q_OBJECT
-
 public:
-	explicit Editor(ObjectList *list, QWidget * = 0);
-
+	explicit Editor(const Kolf::ItemFactory& factory, QWidget * = 0);
 signals:
 	void changed();
-	void addNewItem(Object *);
-
-public slots:
+	void addNewItem(const QString&);
+public Q_SLOTS:
 	void setItem(CanvasItem *);
-
-private slots:
-	void listboxExecuted(Q3ListBoxItem *); //Q3ListBoxItem used here because that is what KListBox uses
-
-
+private Q_SLOTS:
+	void listboxExecuted(QListWidgetItem*);
 private:
-	ObjectList *list;
+	const Kolf::ItemFactory& m_factory;
 	QHBoxLayout *hlayout;
-	K3ListBox *listbox; //note: this uses Q3 listbox
+	KListWidget* m_typeList;
 	Config *config;
 };
 
