@@ -105,9 +105,8 @@ public:
     bool allowedToStartNewGame();
     int moveCount() const;
 
-    QString save_it();
-    void saveGame(QDomDocument &doc);
-    void openGame(QDomDocument &doc);
+    void saveGame( QIODevice * io );
+    void openGame( QIODevice * io );
     virtual void mapOldId(int id);
     virtual int oldId() const;
     void recordGameStatistics();
