@@ -84,24 +84,25 @@ public:
 
     virtual void resizeScene( const QSize & size );
     virtual void relayoutScene();
-    virtual void relayoutPiles( int duration = 0);
+    virtual void recalculatePileLayouts();
 
     virtual void addPile( KCardPile * pile );
     virtual void removePile( KCardPile * pile );
     QList<KCardPile*> piles() const;
 
-    QRectF spaceAllottedToPile( const KCardPile * pile ) const;
-
     void setHighlightedItems( QList<QGraphicsItem*> items );
     void clearHighlightedItems();
     QList<QGraphicsItem*> highlightedItems() const;
 
-    virtual void moveCardsToPile( QList<KCard*> cards, KCardPile * pile, int duration );
+    void moveCardsToPile( const QList<KCard*> & cards, KCardPile * pile, int duration );
     void moveCardToPile( KCard * card, KCardPile * pile, int duration );
+    void moveCardsToPileAtSpeed( const QList<KCard*> & cards, KCardPile * pile, qreal velocity );
     void moveCardToPileAtSpeed( KCard * card, KCardPile * pile, qreal velocity );
-    void flipCardsToPile( QList<KCard*> cards, KCardPile * pile, int duration );
+    void flipCardsToPile( const QList<KCard*> & cards, KCardPile * pile, int duration );
     void flipCardToPile( KCard * card, KCardPile * pile, int duration );
+    void flipCardsToPileAtSpeed( const QList<KCard*> & cards, KCardPile * pile, qreal velocity );
     void flipCardToPileAtSpeed( KCard * card, KCardPile * pile, qreal velocity );
+    void updatePileLayout( KCardPile * pile, int duration );
 
     bool isCardAnimationRunning() const;
 
@@ -131,9 +132,9 @@ protected:
 
     virtual bool allowedToAdd( const KCardPile * pile, const QList<KCard*> & cards ) const;
     virtual bool allowedToRemove( const KCardPile * pile, const KCard * card ) const;
-    virtual KCardPile * targetPile();
 
-    virtual void setItemHighlight( QGraphicsItem * item, bool highlight );
+    virtual void cardsDroppedOnPile( const QList<KCard*> & cards, KCardPile * pile );
+    virtual void cardsMoved( const QList<KCard*> & cards, KCardPile * oldPile, KCardPile * newPile );
 
     virtual void mouseDoubleClickEvent( QGraphicsSceneMouseEvent * e );
     virtual void mouseMoveEvent( QGraphicsSceneMouseEvent * e );
